@@ -122,7 +122,7 @@ data = {
         "HFE347mcc3": 575.0,
         "HFE347pcf2": 580.0,
         "HFE356pcc3": 110.0,
-        "HFE449sl": 297.0,
+        "HFE449s1": 297.0,
         "HFE569sf2": 59.0,
         "HFE4310pccc124": 1870.0,
         "HFE236ca12": 2800.0,
@@ -197,7 +197,7 @@ data = {
         "HFE347mcc3": 530.0,
         "HFE347pcf2": 889.0,
         "HFE356pcc3": 413.0,
-        "HFE449sl": 421.0,
+        "HFE449s1": 421.0,
         "HFE569sf2": 57.0,
         "HFE4310pccc124": 2820.0,
         "HFE236ca12": 5350.0,
@@ -288,7 +288,7 @@ data = {
         "HFE347mcc3": 641,
         "HFE347pcf2": 1072,
         "HFE356pcc3": 500,
-        "HFE449sl": 509,
+        "HFE449s1": 509,
         "HFE569sf2": 69,
         "HFE4310pccc124": 3353,
         "HFE236ca12": 6260,
@@ -378,7 +378,7 @@ data = {
         "HFE347mcc3": 576.0,
         "HFE347pcf2": 980.0,
         "HFE356pcc3": 277.0,
-        "HFE449sl": 460.0,
+        "HFE449s1": 460.0,
         "HFE569sf2": 60.7,
         "HFE4310pccc124": 3220.0,
         "HFE236ca12": 6060.0,
@@ -401,4 +401,93 @@ data = {
         "CH3Cl": 5.54,
         "Halon1201": 380.0,
     },
+    "AR6GWP20": {
+        "CH4": 81.2,
+        "N2O": 273.0,
+        "CFC11": 7430.0,
+        "CFC12": 11400.0,
+        "CFC13": 12400.0,
+        "CFC113": 6860.0,
+        "CFC114": 8260.0,
+        "CFC115": 7410.0,
+        "Halon1301": 8320.0,
+        "Halon1211": 4920.0,
+        "Halon2402": 4070.0,
+        "Halon1202": 775.0,
+        "CCl4": 3810.0,
+        "CH3Br": 8.74,
+        "CH3CCl3": 567.0,
+        "HCFC21": 575.0,
+        "HCFC22": 5690.0,
+        "HCFC123": 325.0,
+        "HCFC124": 2070.0,
+        "HCFC141b": 2710.0,
+        "HCFC142b": 5510.0,
+        "HCFC225ca": 491.0,
+        "HCFC225cb": 1960.0,
+        "HFC23": 12400.0,
+        "HFC32": 2690.0,
+        "HFC41": 485.0,
+        "HFC125": 6740.0,
+        "HFC134": 3900.0,
+        "HFC134a": 4140.0,
+        "HFC143": 1300.0,
+        "HFC143a": 7840.0,
+        "HFC152": 77.6,
+        "HFC152a": 591.0,
+        "HFC161": 17.4,
+        "HFC227ea": 5850.0,
+        "HFC236cb": 3750.0,
+        "HFC236ea": 4420.0,
+        "HFC236fa": 7450.0,
+        "HFC245ca": 2680.0,
+        "HFC245fa": 3170.0,
+        "HFC365mfc": 2920.0,
+        "HFC4310mee": 3960.0,
+        "SO2F2": 7510.0,
+        "SF6": 18300.0,
+        "NF3": 13400.0,
+        "CF4": 5300.0,
+        "C2F6": 8940.0,
+        "C3F8": 6770.0,
+        "cC4F8": 7400.0,
+        "C4F10": 7300.0,
+        "C5F12": 6680.0,
+        "C6F14": 6260.0,
+        "C7F16": 6120.0,
+        "C8F18": 6010.0,
+        "C10F18": 5480.0,
+        "SF5CF3": 13900.0,
+        "HFE125": 13500.0,
+        "HFE134": 12700.0,
+        "HFE143a": 2170.0,
+        "HCFE235da2": 1930.0,
+        "HFE245cb2": 2630.0,
+        "HFE245fa2": 3060.0,
+        "HFE347mcc3": 2020.0,
+        "HFE347pcf2": 3370.0,
+        "HFE356pcc3": 995.0,
+        "HFE449s1": 1620.0,
+        "HFE569sf2": 219.0,
+        "HFE4310pccc124": 8720.0,
+        "HFE236ca12": 11700.0,
+        "HFE338pcc13": 9180.0,
+        "HFE227ea": 9800.0,
+        "HFE236ea2": 7020.0,
+        "HFE236fa": 3670.0,
+        "HFE245fa1": 3170.0,
+        "HFE329mcc2": 7550.0,
+        "HFE338mcf2": 3460.0,
+        "HFE347mcf2": 3270.0,
+        "HFE356mec3": 949.0,
+        "HFE356pcf2": 2870.0,
+        "HFE356pcf3": 1730.0,
+        "HFE365mcf3": 5.77,
+        "HFE374pc2": 45.0,
+        "PFPMIE": 7750.0,
+        "CHCl3": 74.2,
+        "CH2Cl2": 40.2,
+        "CH3Cl": 19.9,
+        "Halon1201": 1340.0,
+    },
 }
